@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
+  Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 
   All rights reserved.
 
@@ -32,7 +32,7 @@
 */
 
 /*
- * uimΥХåؿ
+ * uimのコールバック関数
  */
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -57,7 +57,7 @@
 #include <uim/uim-helper.h>
 #include <uim/uim-util.h>
 
-/* ơ饤κ */
+/* ステータスラインの最大幅 */
 static int s_max_width;
 static char *s_commit_str;
 static char *s_statusline_str;
@@ -93,23 +93,23 @@ static void reset_candidate(void);
 static void set_candidate(void);
 
 struct candidate_tag {
-  /* ο */
+  /* 候補の数 */
   int nr;
-  /* 1٤ɽ */
+  /* 1度に表示する候補数 */
   int limit;
-  /* page */
+  /* 総page数 */
   int nr_pages;
-  /* ߤθ 0Ϥޤ */
+  /* 現在の候補 0から始まる */
   int index;
-  /* ߤΥڡ 0Ϥޤ */
+  /* 現在のページ 0から始まる */
   int page;
-  /* ڡʸ ǿnr_pages */
+  /* ページ文字列の配列 要素数nr_pages */
   char **page_strs;
-  /* ΰ֤ ǿnr */
+  /* 候補の位置の配列 要素数nr */
   int *cand_col;
-  /* ڡκǽθindex ǿnr_pages */
+  /* ページの最初の候補のindexの配列 要素数nr_pages */
   int *page2index;
-  /* ߤθΥǥå褹륫 */
+  /* 現在の候補のインデックスを描画するカラム */
   int *index_col;
 };
 
@@ -126,7 +126,7 @@ static struct candidate_tag s_candidate = {
 };
 
 /*
- * 
+ * 初期化
  */
 void init_callbacks(void)
 {
@@ -157,7 +157,7 @@ void init_callbacks(void)
 
     if (uim_iconv->is_convertible(enc = get_enc(), "EUC-JP")) {
       void *cd = uim_iconv->create(enc, "EUC-JP");
-      s_nokori_str = uim_iconv->convert(cd, "Ĥ");
+      s_nokori_str = uim_iconv->convert(cd, "残り");
       if (cd) {
         uim_iconv->release(cd);
       }
@@ -186,7 +186,7 @@ int press_key(int key, int key_state)
 
 
 /*
- * ̾ʶ路uim¦׵ᤵ줿Ƥ֡
+ * 名前が紛らわしいが、uim側から描画を要求されたら呼ぶ。
  */
 void start_callbacks(void)
 {
@@ -199,7 +199,7 @@ void start_callbacks(void)
 }
 
 /*
- * ХåؿƤФƤʤСFALSE֤
+ * コールバック関数が呼ばれていなければ、FALSEを返す
  */
 int end_callbacks(void)
 {
@@ -210,7 +210,7 @@ int end_callbacks(void)
 
   s_start_callbacks = FALSE;
 
-  /* cursorꤵƤʤȤϥץꥨǥåȤˤ */
+  /* cursorが指定されていないときはプリエディットの末尾にする */
   if (s_preedit->cursor == UNDEFINED) {
     s_preedit->cursor = s_preedit->width;
   }
@@ -242,8 +242,8 @@ int end_callbacks(void)
 }
 
 /*
- * ʸ֤
- * ֤ͤfree
+ * 確定文字列を返す
+ * 返り値はfreeする
  */
 char *get_commit_str(void)
 {
@@ -257,8 +257,8 @@ char *get_commit_str(void)
 }
 
 /*
- * ʸ֤
- * ֤ͤfree
+ * 候補一覧文字列を返す
+ * 返り値はfreeする
  */
 char *get_statusline_str(void)
 {
@@ -267,8 +267,8 @@ char *get_statusline_str(void)
 }
 
 /*
- * ʸ֤
- * ֤ͤfree
+ * 選択文字列を返す
+ * 返り値はfreeする
  */
 char *get_candidate_str(void)
 {
@@ -277,8 +277,8 @@ char *get_candidate_str(void)
 }
 
 /*
- * 򤵤Ƥcolumn֤
- * 򤵤ƤʤȤUNDEFINED֤
+ * 選択されている候補のcolumnを返す
+ * 選択されていないときはUNDEFINEDを返す
  */
 int get_candidate_col(void)
 {
@@ -287,8 +287,8 @@ int get_candidate_col(void)
 }
 
 /*
- * 򤵤ƤΥǥåʸ֤
- * ֤ͤfree
+ * 選択されている候補のインデックスの文字列を返す
+ * 返り値はfreeする
  */
 char *get_index_str(void)
 {
@@ -297,8 +297,8 @@ char *get_index_str(void)
 }
 
 /*
- * s_index_str褹륫֤
- * 򤵤ƤʤȤUNDEFINED֤
+ * s_index_strを描画するカラムを返す
+ * 選択されていないときはUNDEFINEDを返す
  */
 int get_index_col(void)
 {
@@ -311,8 +311,8 @@ int get_index_col(void)
 }
 
 /*
- * ץꥨǥåȤ֤
- * ֤ͤfree
+ * プリエディットを返す
+ * 返り値はfreeする
  */
 struct preedit_tag *get_preedit(void)
 {
@@ -321,7 +321,7 @@ struct preedit_tag *get_preedit(void)
 }
 
 /*
- * ߤΥ⡼ɤ֤
+ * 現在のモードを返す
  */
 int get_mode(void)
 {
@@ -330,8 +330,8 @@ int get_mode(void)
 }
 
 /*
- * ߤΥ⡼ʸ֤
- * ֤ͤNULLˤʤ뤳ȤϤʤfreeɬפ
+ * 現在のモード文字列を返す
+ * 返り値はNULLになることはなく、freeする必要がある
  */
 char *get_mode_str(void)
 {
@@ -370,10 +370,10 @@ static void switch_system_global_im_cb(void *ptr, const char *name)
 }
 
 /*
- * ɽȤ˸ƤФ롣
- * s_candidate.nr = nr()
- * s_candidate.limit = display_limit(ɽ)
- * s_candidate.cand_colΰݤ롣
+ * 候補一覧を表示するときに呼ばれる。
+ * s_candidate.nr = nr(候補総数)
+ * s_candidate.limit = display_limit(表示する候補数)
+ * s_candidate.cand_colの領域を確保する。
  * s_candidate.page = 0 (initial page)
  */
 static void activate_cb(void *ptr, int nr, int display_limit)
@@ -386,7 +386,7 @@ static void activate_cb(void *ptr, int nr, int display_limit)
 }
 
 /*
- * 䤬򤵤줿Ȥ˸ƤФ롣
+ * 候補が選択されたときに呼ばれる。
  * s_candidate.index = index
  */
 static void select_cb(void *ptr, int index)
@@ -413,9 +413,9 @@ static void select_cb(void *ptr, int index)
 }
 
 /*
- * ڡѤȤ˸ƤФ롣
- * s_candidate.page = 1ڡ(directionˤ)
- * s_candidate.index = pageκǽ餫Ǹ(directionˤ)
+ * ページを変えたときに呼ばれる。
+ * s_candidate.page = 1ページ前か後(directionによる)
+ * s_candidate.index = pageの最初か最後(directionによる)
  */
 static void shift_page_cb(void *ptr, int direction)
 {
@@ -438,8 +438,8 @@ static void shift_page_cb(void *ptr, int direction)
 }
 
 /*
- * äȤ˸ƤФ롣
- * reset_candidateƤ֡
+ * 候補一覧を消すときに呼ばれる。
+ * reset_candidateを呼ぶ。
  */
 static void deactivate_cb(void *ptr)
 {
@@ -475,8 +475,8 @@ static void clear_cb(void *ptr)
 }
 
 /*
- * clear_cbθ0ʾƤФ
- * s_preedit
+ * clear_cbの後に0回以上呼ばれる
+ * s_preeditを構成する
  */
 static void pushback_cb(void *ptr, int attr, const char *str)
 {
@@ -494,17 +494,17 @@ static void pushback_cb(void *ptr, int attr, const char *str)
   }
 
   start_callbacks();
-  /* UPreeditAttr_CursorΤȤ˶ʸȤϸ¤ʤ */
+  /* UPreeditAttr_Cursorのときに空文字列とは限らない */
   if (attr & UPreeditAttr_Cursor) {
-    /* skkμϿϥ뤬2սꤢ */
+    /* skkの辞書登録はカーソルが2箇所ある */
     /* assert(s_preedit->cursor == UNDEFINED); */
     s_preedit->cursor = s_preedit->width;
     attr -= UPreeditAttr_Cursor;
     cursor = TRUE;
   }
-  /* ʸ̵ */
+  /* 空文字列は無視 */
   if (width > 0) {
-    /* ֤ʸȿžʤ */
+    /* カーソル位置の文字を反転させない */
     if (g_opt.cursor_no_reverse && cursor && attr & UPreeditAttr_Reverse && s_preedit->cursor != UNDEFINED) {
       int *rval = width2byte2(str, 1);
       int first_char_byte = rval[0];
@@ -520,7 +520,7 @@ static void pushback_cb(void *ptr, int attr, const char *str)
         return;
       }
     }
-    /* attrƱʸդ­ */
+    /* attrが前と同じ場合は前の文字列に付け足す */
     if (s_preedit->nr_psegs > 0 && s_preedit->pseg[s_preedit->nr_psegs - 1].attr == attr) {
       char *tmp_str = s_preedit->pseg[s_preedit->nr_psegs - 1].str;
 
@@ -543,8 +543,8 @@ static void update_cb(void *ptr)
 }
 
 /*
- * ⡼ɤѤäȤ˸ƤФ롣
- * ºݤѤäƤʤȤ⤢롣
+ * モードが変わったときに呼ばれる。
+ * 実際は変わっていないこともある。
  */
 static void mode_update_cb(void *ptr, int mode)
 {
@@ -561,7 +561,7 @@ static void mode_update_cb(void *ptr, int mode)
 static void prop_list_update_cb(void *ptr, const char *str)
 {
   char *line;
-  int error = TRUE; /* str  "" ΤȤerrorˤ*/
+  int error = TRUE; /* str が "" のときはerrorにする*/
   char *labels = uim_strdup("");
   char *dup_str;
 
@@ -684,7 +684,7 @@ loop_end:
 }
 
 /*
- * ץꥨǥåȤꡤݥ󥿤֤
+ * 新しいプリエディットを作り，ポインタを返す
  */
 struct preedit_tag *create_preedit(void)
 {
@@ -697,7 +697,7 @@ struct preedit_tag *create_preedit(void)
 }
 
 /*
- * pΰ
+ * pの領域を開放する
  */
 void free_preedit(struct preedit_tag *p)
 {
@@ -713,7 +713,7 @@ void free_preedit(struct preedit_tag *p)
 }
 
 /*
- * pʣꡤݥ󥿤֤
+ * pの複製を作り，ポインタを返す
  */
 static struct preedit_tag *dup_preedit(struct preedit_tag *p)
 {
@@ -769,18 +769,18 @@ static void init_candidate(int nr, int display_limit)
 }
 
 /*
- * s_candidate.page_strs = ڡʸ
- * ʸs_max_widthۤȤϡϤ߽Ф򼡤Υڡ˰ܤ
- * 1Ĥ䤬ʤƤϤ߽ФȤϡܤʤ
- * s_max_widthüץǻꤵ줿
- * s_candidate.page2index = ڡκǽθindex
- * s_candidate.cand_col = ΰ
- * s_candidate.nr_pages = ڡ
- * s_candidate.index_col = ΥǥåΥ
+ * s_candidate.page_strs = ページ文字列の配列
+ * 文字列の幅がs_max_widthを越えたときは、はみ出た候補を次のページに移す。
+ * 1つしか候補がなくてはみ出たときは、移さない。
+ * s_max_widthは端末の幅かオプションで指定された値
+ * s_candidate.page2index = ページの最初の候補のindex
+ * s_candidate.cand_col = 候補の位置
+ * s_candidate.nr_pages = ページの総数
+ * s_candidate.index_col = 候補のインデックスのカラム
  */
 static void make_page_strs(void)
 {
-  /* NULLreallocƥߤˤʤʤ褦 */
+  /* NULLをreallocしてゴミにならないように */
   char *page_str = uim_strdup("");
   int page_byte = 0;
   int page_width = 0;
@@ -801,10 +801,10 @@ static void make_page_strs(void)
     nr_in_virtual_page = s_candidate.nr - start;
 
   for (index = start; index < (start + nr_in_virtual_page); index++) {
-    /* A:  S:  D:  F:  J:  K:  L:  [Ĥ 227] */
+    /* A:工  S:広  D:向  F:考  J:構  K:敲  L:後  [残り 227] */
     int next = FALSE; /* flag whether to finish page */
     int add_extra_page = FALSE;
-    /* "[10/20]"  */
+    /* "[10/20]" の幅 */
     int index_width;
     uim_candidate cand = uim_get_candidate(g_context, index, index_in_page);
     const char *cand_str_label = uim_candidate_get_heading_label(cand);
@@ -825,7 +825,7 @@ static void make_page_strs(void)
     free(cand_str_cand);
 
     if (page_width + cand_width + index_width > s_max_width && index_in_page != 0) {
-      /* Ϥ߽ФΤǼΥڡ˰ܤ */
+      /* はみ出たので次のページに移す */
       index--;
       if (g_opt.ddskk) {
         index_width = strlen("[xxxx ]") + numwidth(s_candidate.nr - index - 1);
@@ -839,12 +839,12 @@ static void make_page_strs(void)
       s_candidate.cand_col[index] = page_width + cand_label_width + strlen(":");
 
       if (cand_width + index_width > s_max_width && index_in_page == 0) {
-        /* Ϥ߽Ф˰ܤʤ */
+        /* はみ出たが、次に移さない */
         assert(page_width == 0);
         next = TRUE;
-                                                  /* 1ʸ */
+                                                  /* 全角1文字の幅 */
         if (s_max_width >= cand_label_width + (int)strlen(":") + 2 + (int)strlen(" ") + index_width) {
-          /*  + ǥå */
+          /* 候補 + インデックス */
 
           cand_width = s_max_width - index_width - strlen(" ");
           cand_width = strhead(cand_str, cand_width);
@@ -854,7 +854,7 @@ static void make_page_strs(void)
           cand_str[cand_byte++] = ' ';
           cand_str[cand_byte] = '\0';
         } else {
-          /* ǥåϤʤ */
+          /* インデックスはなし */
 
           index_width = UNDEFINED;
           if (cand_width > s_max_width) {
@@ -910,7 +910,9 @@ static void make_page_strs(void)
         free(old_str);
         free(index_str);
       }
-      free(s_candidate.page_strs[page]);
+      if (page < s_candidate.nr_pages) {
+        free(s_candidate.page_strs[page]);
+      }
       s_candidate.page_strs[page] = uim_strdup(page_str);
       page++; 
 
@@ -943,8 +945,8 @@ static void make_page_strs(void)
 }
 
 /*
- * nʸɽ֤
- * n0ʾǤʤФʤʤ
+ * nの文字列表現の幅を返す
+ * nは0以上でなければならない。
  */
 static int numwidth(int n)
 {
@@ -955,7 +957,7 @@ static int numwidth(int n)
 }
 
 /*
- * indexڡ֤
+ * indexがあるページを返す。
  */
 static int index2page(int index)
 {
@@ -970,7 +972,7 @@ static int index2page(int index)
 }
 
 /*
- * s_candidate롣
+ * s_candidateを初期化する。
  */
 static void reset_candidate(void)
 {
@@ -1006,24 +1008,24 @@ static void reset_candidate(void)
 }
 
 /*
- * s_candidate_cols_candidate_strs_index_strꤹ
+ * s_candidate_colとs_candidate_strとs_index_strを設定する
  */
 static void set_candidate(void)
 {
   uim_candidate cand;
   int cand_width;
-  /* "[10/20]" */
+  /* "[10/20]"の幅 */
   int index_width;
 
   if (s_candidate.index_col[s_candidate.page] == UNDEFINED) {
     s_index_str = uim_strdup("");
     index_width = 0;
   } else {
-    /* üθΥǥå */
+    /* 右端の候補のインデックス */
     int right_edge_cand_index = s_candidate.page + 1 == s_candidate.nr_pages ? s_candidate.nr - 1 : s_candidate.page2index[s_candidate.page + 1] - 1;
-    /* üθΥǥå */
+    /* 右端の候補のインデックスの幅 */
     int right_edge_cand_index_width = numwidth(right_edge_cand_index + 1);
-    /* ߤθΥǥå */
+    /* 現在の候補のインデックスの幅 */
     int cand_index_width = numwidth(s_candidate.index + 1);
     int padlen = right_edge_cand_index_width - cand_index_width;
     char *pad;
@@ -1079,7 +1081,7 @@ void callbacks_winch(void)
     return;
   }
 
-  /* ɽ */
+  /* 候補一覧を表示中 */
   if (s_candidate.page_strs != NULL) {
     int i;
     for (i = 0; i < s_candidate.nr_pages; i++) {
