@@ -1,6 +1,6 @@
 /*
 
-  copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
+  copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 
   All rights reserved.
 
@@ -68,7 +68,11 @@ static gboolean label_draw(GtkWidget *label, cairo_t *cr, gpointer data);
 static gboolean label_exposed(GtkWidget *label, GdkEventExpose *event, gpointer data);
 #endif
 static void clear_button(struct index_button *idxbutton, gint cell_index);
+#if GTK_CHECK_VERSION(3, 4, 0)
+static void show_table(GtkGrid *view, GPtrArray *buttons);
+#else
 static void show_table(GtkTable *view, GPtrArray *buttons);
+#endif
 static void scale_label(GtkEventBox *button, double factor);
 
 
@@ -133,8 +137,13 @@ uim_cand_win_horizontal_gtk_init (UIMCandWinHorizontalGtk *horizontal_cwin)
   horizontal_cwin->buttons = g_ptr_array_new();
   horizontal_cwin->selected = NULL;
 
+#if GTK_CHECK_VERSION(3, 4, 0)
+  cwin->view = gtk_grid_new();
+  gtk_grid_set_column_spacing(GTK_GRID(cwin->view), 10);
+#else
   cwin->view = gtk_table_new(1, DEFAULT_NR_CELLS, FALSE);
   gtk_table_set_col_spacings(GTK_TABLE(cwin->view), 10);
+#endif
   viewport = gtk_viewport_new(NULL, NULL);
   gtk_container_add(GTK_CONTAINER(viewport), cwin->view);
   gtk_container_add(GTK_CONTAINER(cwin->scrolled_window), viewport);
@@ -155,7 +164,13 @@ uim_cand_win_horizontal_gtk_init (UIMCandWinHorizontalGtk *horizontal_cwin)
 #else
     g_signal_connect_after(label, "expose-event", G_CALLBACK(label_exposed), horizontal_cwin);
 #endif
+#if GTK_CHECK_VERSION(3, 4, 0)
+    gtk_widget_set_hexpand(button, TRUE);
+    gtk_widget_set_vexpand(button, TRUE);
+    gtk_grid_attach(GTK_GRID(cwin->view), button, col, 0, 1, 1);
+#else
     gtk_table_attach_defaults(GTK_TABLE(cwin->view), button, col, col + 1, 0, 1);
+#endif
     idxbutton = g_malloc(sizeof(struct index_button));
     if (idxbutton) {
       idxbutton->button = GTK_EVENT_BOX(button);
@@ -283,8 +298,7 @@ button_clicked(GtkEventBox *button, GdkEventButton *event, gpointer data)
   prev_selected = horizontal_cwin->selected;
   if (prev_selected) {
     GtkWidget *label = gtk_bin_get_child(GTK_BIN(prev_selected->button));
-    gtk_widget_unmap(label);
-    gtk_widget_map(label);
+    gtk_widget_queue_draw(label);
   }
 
   for (i = 0; i < (gint)horizontal_cwin->buttons->len; i++) {
@@ -298,8 +312,7 @@ button_clicked(GtkEventBox *button, GdkEventButton *event, gpointer data)
     if (p == button) {
       GtkWidget *label = gtk_bin_get_child(GTK_BIN(button));
       idx = idxbutton->cand_index_in_page;
-      gtk_widget_unmap(label);
-      gtk_widget_map(label);
+      gtk_widget_queue_draw(label);
       horizontal_cwin->selected = idxbutton;
       break;
     }
@@ -379,7 +392,14 @@ assign_cellbutton(UIMCandWinHorizontalGtk *horizontal_cwin,
 #else
     g_signal_connect_after(label, "expose-event", G_CALLBACK(label_exposed), horizontal_cwin);
 #endif
+#if GTK_CHECK_VERSION(3, 4, 0)
+    gtk_widget_set_hexpand(button, TRUE);
+    gtk_widget_set_vexpand(button, TRUE);
+    gtk_grid_attach(GTK_GRID(UIM_CAND_WIN_GTK(horizontal_cwin)->view), button,
+                    cand_index, 0, 1, 1);
+#else
     gtk_table_attach_defaults(GTK_TABLE(UIM_CAND_WIN_GTK(horizontal_cwin)->view), button, cand_index, cand_index + 1, 0, 1);
+#endif
     idxbutton = g_malloc(sizeof(struct index_button));
     if (idxbutton) {
       idxbutton->button = GTK_EVENT_BOX(button);
@@ -432,12 +452,10 @@ uim_cand_win_horizontal_gtk_set_index(UIMCandWinHorizontalGtk *horizontal_cwin,
     prev_selected = (gpointer)horizontal_cwin->selected;
     if (prev_selected && prev_index != cwin->candidate_index) {
       label = gtk_bin_get_child(GTK_BIN(prev_selected->button));
-      gtk_widget_unmap(label);
-      gtk_widget_map(label);
+      gtk_widget_queue_draw(label);
     }
     label = gtk_bin_get_child(GTK_BIN(idxbutton->button));
-    gtk_widget_unmap(label);
-    gtk_widget_map(label);
+    gtk_widget_queue_draw(label);
     horizontal_cwin->selected = idxbutton;
 
     /* show subwin */
@@ -580,8 +598,9 @@ update_table_button(UIMCandWinHorizontalGtk *horizontal_cwin, guint new_page)
       g_free(idxbutton);
       g_ptr_array_remove_index(buttons, i);
     }
-
+#if !GTK_CHECK_VERSION(3, 4, 0)
     gtk_table_resize(GTK_TABLE(cwin->view), 1, cand_index);
+#endif
   }
 }
 
@@ -607,7 +626,11 @@ uim_cand_win_horizontal_gtk_set_page(UIMCandWinHorizontalGtk *horizontal_cwin, g
     new_page = page;
 
   update_table_button(horizontal_cwin, new_page);
+#if GTK_CHECK_VERSION(3, 4, 0)
+  show_table(GTK_GRID(cwin->view), horizontal_cwin->buttons);
+#else
   show_table(GTK_TABLE(cwin->view), horizontal_cwin->buttons);
+#endif
 
   cwin->page_index = new_page;
 
@@ -629,7 +652,11 @@ uim_cand_win_horizontal_gtk_set_page(UIMCandWinHorizontalGtk *horizontal_cwin, g
 }
 
 static void
+#if GTK_CHECK_VERSION(3, 4, 0)
+show_table(GtkGrid *view, GPtrArray *buttons)
+#else
 show_table(GtkTable *view, GPtrArray *buttons)
+#endif
 {
   gint col;
 
