@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
+Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 
 All rights reserved.
 
@@ -33,10 +33,15 @@ SUCH DAMAGE.
 #include "chargridview.h"
 
 #include <QtGui/QFont>
-#include <QtGui/QHeaderView>
 #include <QtGui/QMouseEvent>
 #include <QtGui/QResizeEvent>
-#include <QtGui/QScrollBar>
+#if QT_VERSION < 0x050000
+# include <QtGui/QHeaderView>
+# include <QtGui/QScrollBar>
+#else
+# include <QtWidgets/QHeaderView>
+# include <QtWidgets/QScrollBar>
+#endif
 
 static const int COLS = 10;
 
@@ -49,14 +54,22 @@ CharGridView::CharGridView( int x, int y, QWidget *parent )
     header->setVisible( false );
     for ( int i = 0; i < x; i++)
     {
+#if QT_VERSION < 0x050000
         header->setResizeMode( i, QHeaderView::Fixed );
+#else
+        header->setSectionResizeMode( i, QHeaderView::Fixed );
+#endif
         header->resizeSection( i, 30 );
     }
     header = verticalHeader();
     header->setVisible( false );
     for ( int i = 0; i < y; i++)
     {
+#if QT_VERSION < 0x050000
         header->setResizeMode( i, QHeaderView::Fixed );
+#else
+        header->setSectionResizeMode( i, QHeaderView::Fixed );
+#endif
         header->resizeSection( i, 30 );
     }
     setSelectionBehavior( QAbstractItemView::SelectItems );
@@ -131,13 +144,21 @@ void CharGridView::setCharacters( const QStringList &charList )
     QHeaderView *header = horizontalHeader();
     for ( int i = prevCols + 1; i < cols; i++)
     {
+#if QT_VERSION < 0x050000
         header->setResizeMode( i, QHeaderView::Fixed );
+#else
+        header->setSectionResizeMode( i, QHeaderView::Fixed );
+#endif
         header->resizeSection( i, header->sectionSize( 0 ) );
     }
     header = verticalHeader();
     for ( int i = prevRows + 1; i < rows; i++)
     {
+#if QT_VERSION < 0x050000
         header->setResizeMode( i, QHeaderView::Fixed );
+#else
+        header->setSectionResizeMode( i, QHeaderView::Fixed );
+#endif
         header->resizeSection( i, header->sectionSize( 0 ) );
     }
     for ( int i = 0; i < rows; i++)
