@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
+Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 
 All rights reserved.
 
@@ -33,7 +33,12 @@ SUCH DAMAGE.
 #ifndef UIM_QT4_CHARDICT_CHAR_GRID_VIEW_H
 #define UIM_QT4_CHARDICT_CHAR_GRID_VIEW_H
 
-#include <QtGui/QTableWidget>
+#include <QtCore/QtGlobal>
+#if QT_VERSION < 0x050000
+# include <QtGui/QTableWidget>
+#else
+# include <QtWidgets/QTableWidget>
+#endif
 
 class QFont;
 class QMouseEvent;
