@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
+Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 
 All rights reserved.
 
@@ -36,13 +36,23 @@ SUCH DAMAGE.
 
 #include <QtCore/QSettings>
 #include <QtCore/QTextStream>
-#include <QtGui/QFrame>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QListWidget>
-#include <QtGui/QListWidgetItem>
-#include <QtGui/QSplitter>
-#include <QtGui/QVBoxLayout>
+#if QT_VERSION < 0x050000
+# include <QtGui/QFrame>
+# include <QtGui/QHBoxLayout>
+# include <QtGui/QLabel>
+# include <QtGui/QListWidget>
+# include <QtGui/QListWidgetItem>
+# include <QtGui/QSplitter>
+# include <QtGui/QVBoxLayout>
+#else
+# include <QtWidgets/QFrame>
+# include <QtWidgets/QHBoxLayout>
+# include <QtWidgets/QLabel>
+# include <QtWidgets/QListWidget>
+# include <QtWidgets/QListWidgetItem>
+# include <QtWidgets/QSplitter>
+# include <QtWidgets/QVBoxLayout>
+#endif
 
 class UnicodeBlock
 {
@@ -322,7 +332,8 @@ void UnicodeViewWidget::setupWidgets()
     {
         const QString uBlockName = uBlocks[ i ].getName();
         QByteArray originalArray;
-        originalArray += "chardict" GETTEXT_CONTEXT_GLUE + uBlockName.toAscii();
+        originalArray += "chardict" GETTEXT_CONTEXT_GLUE
+            + uBlockName.toLatin1();
         const char *original = originalArray.constData();
         QString translation = mygettext( original );
         if ( translation == original )
