@@ -1,7 +1,7 @@
 /*
 
   Copyright (c) 2004-2005 Kazuki Ohta <mover@hct.zaq.ne.jp>
-  Copyright (c) 2005-2013 uim Project http://code.google.com/p/uim/
+  Copyright (c) 2005-2013 uim Project https://github.com/uim/uim
 
   All rights reserved.
 
@@ -34,17 +34,39 @@
 
 #include "plugin.h"
 
+#include <clocale>
+
 #include <QtCore/QStringList>
-#include <QtGui/QInputContext>
-#ifdef Q_WS_X11
-#include <QtGui/QX11Info>
+#if QT_VERSION < 0x050000
+# ifdef Q_WS_X11
+#  include <QtGui/QX11Info>
+# endif
+# include <QtGui/QInputContext>
+#else
+# if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+#  include <QtX11Extras/QX11Info>
+# endif
+# include <QtCore/qdatastream.h>
+# include <qpa/qplatforminputcontext.h>
 #endif
 
 #include "uim/uim.h"
+#include "uim/uim-scm.h"
 #include "uim/uim-x-util.h"
 #include "uim/counted-init.h"
 
 #include "quiminfomanager.h"
+#if QT_VERSION >= 0x050000
+# undef Bool
+# undef CursorShape
+# undef Expose
+# undef FocusIn
+# undef FocusOut
+# undef FontChange
+# undef KeyPress
+# undef KeyRelease
+# undef None
+#endif
 #include "quiminputcontext_with_slave.h"
 
 #define UIM_QT_LIST_SUBIM_AS_QTIM 0
@@ -68,8 +90,18 @@ QStringList UimInputContextPlugin::keys() const
     return createImList();
 }
 
+#if QT_VERSION < 0x050000
 QInputContext *UimInputContextPlugin::create( const QString & key )
+#else
+QPlatformInputContext *UimInputContextPlugin::create( const QString & key, const QStringList & paramList )
+#endif
 {
+    if (qgetenv("__UIM_CANDWIN_CALLED") == QByteArray("STARTED"))
+	return NULL;
+
+#if QT_VERSION >= 0x050000
+    Q_UNUSED(paramList);
+#endif
     QString imname;
 
 #if UIM_QT_LIST_SUBIM_AS_QTIM
@@ -80,11 +112,17 @@ QInputContext *UimInputContextPlugin::create( const QString & key )
     if ( key == "uim" )
         imname = uim_get_default_im_name( setlocale( LC_CTYPE, 0 ) );
 
+#if QT_VERSION < 0x050000
     QUimInputContext *uic = new QUimInputContext( imname.toUtf8().data() );
+#else
+    QUimPlatformInputContext *uic
+        = new QUimPlatformInputContext( imname.toUtf8().data() );
+#endif
 
     return uic;
 }
 
+#if QT_VERSION < 0x050000
 QStringList UimInputContextPlugin::languages( const QString & key )
 {
     return createLanguageList( key );
@@ -99,6 +137,7 @@ QString UimInputContextPlugin::description( const QString & key )
 {
     return displayName( key ) + ": an input method provided via the uim input method framework";
 }
+#endif
 
 QUimInfoManager *
 UimInputContextPlugin::getQUimInfoManager()
@@ -111,6 +150,10 @@ void UimInputContextPlugin::uimInit()
     if ( !uim_counted_init() ) {
         if (!infoManager)
             infoManager = new QUimInfoManager();
+
+	if (uim_scm_c_bool(uim_scm_callf("require-dynlib", "s", "xkb")))
+	    uim_scm_callf("%xkb-set-display", "p", QX11Info::display());
+
 #if UIM_QT_USE_JAPANESE_KANA_KEYBOARD_HACK
         uim_x_kana_input_hack_init( QX11Info::display() );
 #endif
@@ -164,6 +207,7 @@ QStringList UimInputContextPlugin::createImList() const
     return lst;
 }
 
+#if QT_VERSION < 0x050000
 QStringList UimInputContextPlugin::createLanguageList( const QString &key ) const
 {
     if ( key == "uim" )
@@ -193,5 +237,8 @@ QStringList UimInputContextPlugin::createLanguageList( const QString &key ) cons
 
     return QStringList( "" );
 }
+#endif
 
+#if QT_VERSION < 0x050000
 Q_EXPORT_PLUGIN2( uiminputcontextplugin, UimInputContextPlugin )
+#endif
