@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2003-2012 uim Project http://code.google.com/p/uim/
+Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 
 All rights reserved.
 
@@ -43,15 +43,27 @@ SUCH DAMAGE.
 
 #include "plugin.h"
 #include "quiminfomanager.h"
-#include "quiminputcontext.h"
+#if QT_VERSION < 0x050000
+# include "quiminputcontext.h"
+#else
+# include <quimplatforminputcontext.h>
+#endif
 
 static int im_uim_fd = 0;
 static QSocketNotifier *notifier = 0;
 
+#if QT_VERSION < 0x050000
 extern QUimInputContext *focusedInputContext;
+#else
+extern QUimPlatformInputContext *focusedInputContext;
+#endif
 extern bool disableFocusedContext;
 
+#if QT_VERSION < 0x050000
 extern QList<QUimInputContext *> contextList;
+#else
+extern QList<QUimPlatformInputContext *> contextList;
+#endif
 
 QUimHelperManager::QUimHelperManager( QObject *parent )
         : QObject( parent )
@@ -66,7 +78,7 @@ QUimHelperManager::~QUimHelperManager()
         uim_helper_close_client_fd( im_uim_fd );
 }
 
-void QUimHelperManager::checkHelperConnection()
+void QUimHelperManager::checkHelperConnection(uim_context uc)
 {
     if ( im_uim_fd < 0 )
     {
@@ -77,17 +89,20 @@ void QUimHelperManager::checkHelperConnection()
             notifier = new QSocketNotifier( im_uim_fd, QSocketNotifier::Read );
             connect( notifier, SIGNAL( activated( int ) ),
                               this, SLOT( slotStdinActivated() ) );
+            uim_set_uim_fd(uc, im_uim_fd);
         }
     }
 }
 
 void QUimHelperManager::slotStdinActivated()
 {
-    QString tmp;
-
+    char *tmp;
     uim_helper_read_proc( im_uim_fd );
-    while ( !( tmp = QString::fromUtf8( uim_helper_get_message() ) ).isEmpty() )
-        parseHelperStr( tmp );
+    while ((tmp = uim_helper_get_message()))
+    {
+        parseHelperStr(QString::fromUtf8(tmp));
+        free(tmp);
+    }
 }
 
 void QUimHelperManager::parseHelperStr( const QString &str )
@@ -120,9 +135,9 @@ void QUimHelperManager::parseHelperStr( const QString &str )
 
                     /* convert to unicode */
                     QTextCodec *codec
-                        = QTextCodec::codecForName( charset.toAscii() );
+                        = QTextCodec::codecForName( charset.toLatin1() );
                     if ( codec && !lines[ 2 ].isEmpty() )
-                        commit_str = codec->toUnicode( lines[ 2 ].toAscii() );
+                        commit_str = codec->toUnicode( lines[ 2 ].toLatin1() );
                 } else {
                     commit_str = lines[ 1 ];
                 }
@@ -153,7 +168,11 @@ void QUimHelperManager::parseHelperStr( const QString &str )
         if ( !list.isEmpty() && !list[ 0 ].isEmpty() &&
                 !list[ 1 ].isEmpty() && !list[ 2 ].isEmpty() )
         {
+#if QT_VERSION < 0x050000
             QList<QUimInputContext *>::iterator it;
+#else
+            QList<QUimPlatformInputContext *>::iterator it;
+#endif
             for ( it = contextList.begin(); it != contextList.end(); ++it )
             {
                 uim_prop_update_custom( ( *it )->uimContext(),
@@ -177,7 +196,11 @@ void QUimHelperManager::parseHelperStr( const QString &str )
             UimInputContextPlugin::getQUimInfoManager();
         infoManager->initUimInfo();
 
+#if QT_VERSION < 0x050000
         QList<QUimInputContext *>::iterator it;
+#else
+        QList<QUimPlatformInputContext *>::iterator it;
+#endif
         for ( it = contextList.begin(); it != contextList.end(); ++it ) {
             ( *it )->updatePosition();
             ( *it )->updateStyle();
@@ -203,7 +226,11 @@ void QUimHelperManager::parseHelperStrImChange( const QString &str )
     }
     else if ( str.startsWith( QLatin1String( "im_change_whole_desktop" ) ) )
     {
+#if QT_VERSION < 0x050000
         QList<QUimInputContext *>::iterator it;
+#else
+        QList<QUimPlatformInputContext *>::iterator it;
+#endif
         for ( it = contextList.begin(); it != contextList.end(); ++it )
         {
             uim_switch_im( ( *it )->uimContext(), im_name.toUtf8().data() );
@@ -218,7 +245,11 @@ void QUimHelperManager::parseHelperStrImChange( const QString &str )
     {
         if ( focusedInputContext )
         {
+#if QT_VERSION < 0x050000
             QList<QUimInputContext *>::iterator it;
+#else
+            QList<QUimPlatformInputContext *>::iterator it;
+#endif
             for ( it = contextList.begin(); it != contextList.end(); ++it )
             {
                 uim_switch_im( ( *it )->uimContext(), im_name.toUtf8().data() );
@@ -283,7 +314,11 @@ void QUimHelperManager::helper_disconnect_cb()
 
 void QUimHelperManager::update_prop_list_cb( void *ptr, const char *str )
 {
+#if QT_VERSION < 0x050000
     QUimInputContext *ic = static_cast<QUimInputContext*>( ptr );
+#else
+    QUimPlatformInputContext *ic = static_cast<QUimPlatformInputContext*>( ptr );
+#endif
 
     if ( ic != focusedInputContext || disableFocusedContext )
         return;
@@ -298,7 +333,11 @@ void QUimHelperManager::update_prop_list_cb( void *ptr, const char *str )
 
 void QUimHelperManager::update_prop_label_cb( void *ptr, const char *str )
 {
+#if QT_VERSION < 0x050000
     QUimInputContext *ic = static_cast<QUimInputContext*>( ptr );
+#else
+    QUimPlatformInputContext *ic = static_cast<QUimPlatformInputContext*>( ptr );
+#endif
     if ( ic != focusedInputContext || disableFocusedContext )
         return;
 
