@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2006-2013 uim Project http://code.google.com/p/uim/
+Copyright (c) 2006-2013 uim Project https://github.com/uim/uim
 
 All rights reserved.
 
@@ -35,20 +35,34 @@ SUCH DAMAGE.
 
 #include <cstdlib>
 
-#include <QtGui/QApplication>
 #include <QtGui/QClipboard>
-#include <QtGui/QLineEdit>
-#include <QtGui/QTextEdit>
-#ifdef ENABLE_QT4_QT3SUPPORT
-# include <Qt3Support/Q3TextEdit>
+#if QT_VERSION < 0x050000
+# include <QtGui/QApplication>
+# include <QtGui/QLineEdit>
+# include <QtGui/QTextEdit>
+# ifdef ENABLE_QT4_QT3SUPPORT
+#  include <Qt3Support/Q3TextEdit>
+# endif
+#else
+# include <QtWidgets/QApplication>
+# include <QtWidgets/QLineEdit>
+# include <QtWidgets/QTextEdit>
 #endif
 
-#include "quiminputcontext.h"
+#if QT_VERSION < 0x050000
+# include "quiminputcontext.h"
+#else
+# include <quimplatforminputcontext.h>
+#endif
 
 QUimTextUtil::QUimTextUtil( QObject *parent )
         : QObject( parent )
 {
+#if QT_VERSION < 0x050000
     mIc = static_cast<QUimInputContext *>( parent );
+#else
+    mIc = static_cast<QUimPlatformInputContext *>( parent );
+#endif
     mPreeditSaved = false;
 }
 
@@ -63,7 +77,12 @@ QUimTextUtil::acquire_text_cb( void *ptr, enum UTextArea text_id,
                                char **former, char **latter )
 {
     int err;
+#if QT_VERSION < 0x050000
     QUimInputContext *ic = static_cast<QUimInputContext *>( ptr );
+#else
+    QUimPlatformInputContext *ic
+        = static_cast<QUimPlatformInputContext *>( ptr );
+#endif
     QUimTextUtil *tu = ic->textUtil();
 
     switch ( text_id ) {
@@ -93,7 +112,12 @@ QUimTextUtil::delete_text_cb( void *ptr, enum UTextArea text_id,
                               int former_req_len, int latter_req_len )
 {
     int err;
+#if QT_VERSION < 0x050000
     QUimInputContext *ic = static_cast<QUimInputContext *>( ptr );
+#else
+    QUimPlatformInputContext *ic
+        = static_cast<QUimPlatformInputContext *>( ptr );
+#endif
     QUimTextUtil *tu = ic->textUtil();
 
     switch ( text_id ) {
@@ -119,7 +143,7 @@ QUimTextUtil::acquirePrimaryText( enum UTextOrigin origin,
                                   char **former, char **latter )
 {
     int err;
-#if defined(Q_WS_X11)
+#if defined(Q_WS_X11) || defined(Q_OS_UNIX)
     mWidget = QApplication::focusWidget();
 #else
     return -1;
@@ -527,7 +551,7 @@ QUimTextUtil::acquireSelectionText( enum UTextOrigin origin,
                                     char **former, char **latter )
 {
     int err;
-#if defined(Q_WS_X11)
+#if defined(Q_WS_X11) || defined(Q_OS_UNIX)
     mWidget = QApplication::focusWidget();
 #else
     return -1;
@@ -797,7 +821,7 @@ QUimTextUtil::deletePrimaryText( enum UTextOrigin origin, int former_req_len,
                                  int latter_req_len )
 {
     int err;
-#if defined(Q_WS_X11)
+#if defined(Q_WS_X11) || defined(Q_OS_UNIX)
     mWidget = QApplication::focusWidget();
 #else
     return -1;
@@ -1106,7 +1130,7 @@ QUimTextUtil::deleteSelectionText( enum UTextOrigin origin,
                                    int former_req_len, int latter_req_len )
 {
     int err;
-#if defined(Q_WS_X11)
+#if defined(Q_WS_X11) || defined(Q_OS_UNIX)
     mWidget = QApplication::focusWidget();
 #else
     return -1;
