@@ -1,6 +1,6 @@
 /*
 
- Copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
+ Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 
  All rights reserved.
 
@@ -38,14 +38,25 @@
 #include "qtgettext.h"
 
 #include <QtCore/QPointer>
-#include <QtGui/QFileDialog>
-#include <QtGui/QHeaderView>
-#include <QtGui/QLabel>
-#include <QtGui/QPushButton>
-#include <QtGui/QTableWidget>
-#include <QtGui/QTreeWidget>
-#include <QtGui/QTreeWidgetItem>
-#include <QtGui/QVBoxLayout>
+#if QT_VERSION < 0x050000
+# include <QtGui/QFileDialog>
+# include <QtGui/QHeaderView>
+# include <QtGui/QLabel>
+# include <QtGui/QPushButton>
+# include <QtGui/QTableWidget>
+# include <QtGui/QTreeWidget>
+# include <QtGui/QTreeWidgetItem>
+# include <QtGui/QVBoxLayout>
+#else
+# include <QtWidgets/QFileDialog>
+# include <QtWidgets/QHeaderView>
+# include <QtWidgets/QLabel>
+# include <QtWidgets/QPushButton>
+# include <QtWidgets/QTableWidget>
+# include <QtWidgets/QTreeWidget>
+# include <QtWidgets/QTreeWidgetItem>
+# include <QtWidgets/QVBoxLayout>
+#endif
 
 inline static QString _FU8( const char string[] ) 
 {
@@ -777,7 +788,7 @@ void CustomKeyEdit::slotKeyButtonClicked()
 
         for( int i = 0; i < num; i++ )
         {
-            const char *keystr = keyStrList[i].toAscii().data();
+            const char *keystr = keyStrList[i].toLatin1().data();
 
             struct uim_custom_key *item = (struct uim_custom_key *)malloc(sizeof(struct uim_custom_key));
             item->type        = UCustomKey_Regular;
@@ -1293,7 +1304,11 @@ TableEditForm::TableEditForm( QWidget *parent )
     verticalHeader->setDefaultSectionSize( 
             QFontMetrics( m_table->font() ).height() + 2 );
     QHeaderView *horizontalHeader = m_table->horizontalHeader();
+#if QT_VERSION < 0x050000
     horizontalHeader->setResizeMode( QHeaderView::ResizeToContents );
+#else
+    horizontalHeader->setSectionResizeMode( QHeaderView::ResizeToContents );
+#endif
     horizontalHeader->setStretchLastSection( true );
     connect( m_table, SIGNAL( itemSelectionChanged() ),
             this, SLOT( slotItemSelectionChanged() ) );
