@@ -1,6 +1,6 @@
 /*
 
- Copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
+ Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 
  All rights reserved.
 
@@ -37,10 +37,17 @@
 
 #include <QtCore/QProcess>
 #include <QtGui/QContextMenuEvent>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QMenu>
-#include <QtGui/QMessageBox>
-#include <QtGui/QToolButton>
+#if QT_VERSION < 0x050000
+# include <QtGui/QHBoxLayout>
+# include <QtGui/QMenu>
+# include <QtGui/QMessageBox>
+# include <QtGui/QToolButton>
+#else
+# include <QtWidgets/QHBoxLayout>
+# include <QtWidgets/QMenu>
+# include <QtWidgets/QMessageBox>
+# include <QtWidgets/QToolButton>
+#endif
 
 #include "uim/uim-scm.h"
 #include "qtgettext.h"
@@ -69,7 +76,7 @@ QUimHelperToolbar::QUimHelperToolbar( QWidget *parent, bool isApplet )
         this, SIGNAL( menuRequested( QMenu* ) ) );
 
     const QString ICONDIR = UIM_PIXMAPSDIR;
-    const QString ACTION_ICONDIR = KDE4_ICONDIR "/oxygen/16x16/actions";
+    const QString ACTION_ICONDIR = KDE4_ICONDIR "/oxygen/base/16x16/actions";
     const QSize size( ICON_SIZE, ICON_SIZE );
     m_swicon = QPixmap( ICONDIR + "/im_switcher.png" ).scaled(
         size, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
