@@ -1,6 +1,6 @@
 ;;; google-cgiapi-jp.scm: google-cgiapi-jp for uim.
 ;;;
-;;; Copyright (c) 2011-2013 uim Project http://code.google.com/p/uim/
+;;; Copyright (c) 2011-2013 uim Project https://github.com/uim/uim
 ;;;
 ;;; All rights reserved.
 ;;;
@@ -36,6 +36,7 @@
 (require "http-client.scm")
 (require "json.scm")
 (require "generic-predict.scm")
+(require "util.scm")
 (require-custom "generic-key-custom.scm")
 (require-custom "google-cgiapi-jp-custom.scm")
 (require-custom "google-cgiapi-jp-key-custom.scm")
@@ -62,15 +63,9 @@
 
 (define (google-cgiapi-jp-conversion str opts)
   (define (fromconv str)
-    (let* ((cd (iconv-open "UTF-8" "EUC-JP"))
-           (ret (iconv-code-conv cd str)))
-      (iconv-release cd)
-      ret))
+    (iconv-convert "UTF-8" "EUC-JP" str))
   (define (toconv str)
-    (let* ((cd (iconv-open "EUC-JP" "UTF-8"))
-           (ret (iconv-code-conv cd str)))
-      (iconv-release cd)
-      ret))
+    (iconv-convert "EUC-JP" "UTF-8" str))
   (define (make-query)
     (format "/transliterate?langpair=ja-Hira|ja&text=~a~a"
             (http:encode-uri-string (fromconv str)) opts))
