@@ -1,5 +1,5 @@
 ;;;
-;;; Copyright (c) 2010-2013 uim Project http://code.google.com/p/uim/
+;;; Copyright (c) 2010-2013 uim Project https://github.com/uim/uim
 ;;;
 ;;; All rights reserved.
 ;;;
@@ -28,6 +28,8 @@
 ;;; SUCH DAMAGE.
 ;;;;
 
+(require "util.scm")
+
 (define ja-rk-rule-basic
   '(
     ((("-"). ())("" "" ""))
@@ -408,11 +410,7 @@
           ((output (cadr item))
             (single-output (car output))
             (eucjp->utf8 (lambda (str)
-               (and-let* ((ic (iconv-open "UTF-8" "EUC-JP"))
-                           (converted-str (iconv-code-conv ic str)))
-                 (and ic
-                   (iconv-release ic))
-                 converted-str))))
+                           (iconv-convert "UTF-8" "EUC-JP" str))))
           (or
             (and
               ; ((("k" "a")) ("" "" "")) -> ""
@@ -449,11 +447,7 @@
               (cons next-input '()))))
         (let* ((output (caddr item))
                (utf8->eucjp (lambda (str)
-                 (and-let* ((ic (iconv-open "EUC-JP" "UTF-8"))
-                             (converted-str (iconv-code-conv ic str)))
-                   (and ic
-                     (iconv-release ic))
-                   converted-str)))
+                              (iconv-convert "EUC-JP" "UTF-8" str)))
                (eucjp-output (utf8->eucjp output))
                (eucjp-output-list (string-to-list eucjp-output)))
           (or
