@@ -5,7 +5,7 @@
  *  Copyright (C) 2005      Kazuki Ohta <mover AT hct.zaq.ne.jp>
  *  Copyright (C) 2005-2006 Jun Inoue <jun.lambda AT gmail.com>
  *  Copyright (C) 2005-2006 YAMAMOTO Kengo <yamaken AT bp.iij4u.or.jp>
- *  Copyright (c) 2007 SigScheme Project <uim AT freedesktop.org>
+ *  Copyright (c) 2007-2008 SigScheme Project <uim-en AT googlegroups.com>
  *
  *  All rights reserved.
  *
@@ -140,13 +140,18 @@ call_continuation(ScmObj cont, ScmObj args, ScmEvalState *eval_state,
                   enum ScmValueType need_eval)
 {
     ScmObj ret;
+    scm_int_t args_len;
     DECLARE_INTERNAL_FUNCTION("call_continuation");
 
-    if (!LIST_1_P(args))
-        ERR_OBJ("continuation takes exactly one argument but got", args);
-    ret = CAR(args);
-    if (need_eval)
-        ret = EVAL(ret, eval_state->env);
+    /* (receive (x y) (call/cc (lambda (k) (k 0 1)))) */
+    if (LIST_1_P(args)) {
+        ret = CAR(args);
+        if (need_eval)
+            ret = EVAL(ret, eval_state->env);
+    } else {
+        ret = (need_eval) ? map_eval(args, &args_len, eval_state->env) : args;
+        ret = SCM_MAKE_VALUEPACKET(ret);
+    }
     scm_call_continuation(cont, ret);
     /* NOTREACHED */
 }
@@ -245,8 +250,39 @@ call(ScmObj proc, ScmObj args, ScmEvalState *eval_state,
         proc = EVAL(proc, env);
 
     while (!FUNCP(proc)) {
-        if (CLOSUREP(proc))
-            return call_closure(proc, args, eval_state, need_eval);
+        if (CLOSUREP(proc)) {
+#if SCM_USE_LEGACY_MACRO
+            if (SYNTACTIC_CLOSUREP(proc)) {
+                ScmObj ret;
+                scm_bool toplevelp;
+
+                if (!need_eval)
+                    ERR_OBJ("can't apply/map a macro", proc);
+
+                toplevelp = SCM_DEFINABLE_TOPLEVELP(eval_state);
+
+                ret = call_closure(proc, args, eval_state, SCM_VALTYPE_AS_IS);
+                /* eval the result into an as-is object */
+                ret = SCM_FINISH_TAILREC_CALL(ret, eval_state);
+                /* restore previous env */
+                eval_state->env = env;
+                /* Instruct evaluating returned object again as a syntactic
+                 * form. */
+                eval_state->ret_type = SCM_VALTYPE_NEED_EVAL;
+#if SCM_STRICT_TOPLEVEL_DEFINITIONS
+                /* Workaround to allow toplevel definitions by the returned
+                 * form. See scm_eval(). */
+                if (toplevelp)
+                    eval_state->nest = SCM_NEST_RETTYPE_BEGIN;
+#endif
+
+                return ret;
+            } else
+#endif /* SCM_USE_LEGACY_MACRO */
+            {
+                return call_closure(proc, args, eval_state, need_eval);
+            }
+        }
 #if SCM_USE_HYGIENIC_MACRO
         if (HMACROP(proc)) {
             if (!need_eval)
