@@ -5,7 +5,7 @@
 ;;  About    : unit tests for eqv?
 ;;
 ;;  Copyright (C) 2006 YAMAMOTO Kengo <yamaken AT bp.iij4u.or.jp>
-;;  Copyright (c) 2007 SigScheme Project <uim AT freedesktop.org>
+;;  Copyright (c) 2007-2008 SigScheme Project <uim-en AT googlegroups.com>
 ;;
 ;;  All rights reserved.
 ;;
@@ -34,7 +34,7 @@
 ;;  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 ;;  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-(load "test/unittest.scm")
+(require-extension (unittest))
 
 (define tn test-name)
 (define case-insensitive-symbol? #f)
