@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
+  Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 
   All rights reserved.
 
@@ -94,6 +94,9 @@ struct uim_context_ {
   /* legacy 'property' API */
   char *propstr;
 
+  /* helper system */
+  int uim_fd;
+
   /* commit */
   void (*commit_cb)(void *ptr, const char *str);
   /* preedit */
